searchData={"items":[{"type":"module","title":"Ghibli","doc":"Ghibli keeps the contexts that define your domain\nand business logic.\n\nContexts are also responsible for managing your data, regardless\nif it comes from the database, an external API or others.","ref":"Ghibli.html"},{"type":"module","title":"Ghibli.Fetcher","doc":"Fetches the URL using `HTTPoison` and parses using `Jason` converting keys into atoms.","ref":"Ghibli.Fetcher.html"},{"type":"function","title":"Ghibli.Fetcher.fetch/1","doc":"Uses https://ghibliapi.vercel.app/ as the base url and concats a query to the end. Ensures the `status_code`\nreturns a 200 and parses it using returning a map with atom keys.","ref":"Ghibli.Fetcher.html#fetch/1"},{"type":"function","title":"Examples - Ghibli.Fetcher.fetch/1","doc":"iex> Ghibli.Fetcher.fetch(\"films/5fdfb320-2a02-49a7-94ff-5ca418cae602\")\n    {:ok,\n     %{\n       id: \"5fdfb320-2a02-49a7-94ff-5ca418cae602\",\n       description: \"The film follows Anna Sasaki living with her relatives in the seaside town. Anna comes across a nearby abandoned mansion, where she meets Marnie, a mysterious girl who asks her to promise to keep their secrets from everyone. As the summer progresses, Anna spends more time with Marnie, and eventually Anna learns the truth about her family and foster care.\",\n       title: \"When Marnie Was There\",\n       image: \"https://image.tmdb.org/t/p/w600_and_h900_bestv2/vug1dvDI1tSa60Z8qjCuUE7ntkO.jpg\",\n       url: \"https://ghibliapi.vercel.app/films/5fdfb320-2a02-49a7-94ff-5ca418cae602\",\n       species: [\"https://ghibliapi.vercel.app/species/af3910a6-429f-4c74-9ad5-dfe1c4aa04f2\"],\n       people: [\"https://ghibliapi.vercel.app/people/\"],\n       locations: [\"https://ghibliapi.vercel.app/locations/\"],\n       vehicles: [\"https://ghibliapi.vercel.app/vehicles/\"],\n       original_title: \"思い出のマーニー\",\n       original_title_romanised: \"Omoide no Marnie\",\n       movie_banner: \"https://image.tmdb.org/t/p/original/axUX7urQDwCGQ9qbgh2Yys7qY9J.jpg\",\n       director: \"Hiromasa Yonebayashi\",\n       producer: \"Yoshiaki Nishimura\",\n       release_date: \"2014\",\n       running_time: \"103\",\n       rt_score: \"92\"\n     }}","ref":"Ghibli.Fetcher.html#fetch/1-examples"},{"type":"module","title":"Ghibli.Film","doc":"Logic for fetching Films from the Studio Ghibli API. The response is returned in this\nshape:\n```\n{\n  \"id\": \"2baf70d1-42bb-4437-b551-e5fed5a87abe\",\n  \"title\": \"Castle in the Sky\",\n  \"original_title\": \"天空の城ラピュタ\",\n  \"original_title_romanised\": \"Tenkū no shiro Rapyuta\",\n  \"description\": \"The orphan Sheeta inherited a mysterious crystal that links her to the mythical sky-kingdom of Laputa. With the help of resourceful Pazu and a rollicking band of sky pirates, she makes her way to the ruins of the once-great civilization. Sheeta and Pazu must outwit the evil Muska, who plans to use Laputa's science to make himself ruler of the world.\",\n  \"director\": \"Hayao Miyazaki\",\n  \"producer\": \"Isao Takahata\",\n  \"release_date\": \"1986\",\n  \"running_time\": \"124\",\n  \"rt_score\": \"95\",\n  \"people\": [\n    \"https://ghibliapi.vercel.app/people/\"\n  ],\n  \"species\": [\n    \"https://ghibliapi.vercel.app/species/af3910a6-429f-4c74-9ad5-dfe1c4aa04f2\"\n  ],\n  \"locations\": [\n    \"https://ghibliapi.vercel.app/locations/\"\n  ],\n  \"vehicles\": [\n    \"https://ghibliapi.vercel.app/vehicles/\"\n  ],\n  \"url\": \"https://ghibliapi.vercel.app/films/2baf70d1-42bb-4437-b551-e5fed5a87abe\"\n}\n```","ref":"Ghibli.Film.html"},{"type":"function","title":"Ghibli.Film.all/0","doc":"","ref":"Ghibli.Film.html#all/0"},{"type":"function","title":"Ghibli.Film.get_by/1","doc":"","ref":"Ghibli.Film.html#get_by/1"},{"type":"type","title":"Ghibli.Film.t/0","doc":"","ref":"Ghibli.Film.html#t:t/0"},{"type":"module","title":"Ghibli.Location","doc":"Houses the logic for fetching locations from the Studio Ghibli API. The shape of the\ndata looks as follows:\n```\n{\n  \"id\": \"11014596-71b0-4b3e-b8c0-1c4b15f28b9a\",\n  \"name\": \"Irontown\",\n  \"climate\": \"Continental\",\n  \"terrain\": \"Mountain\",\n  \"surface_water\": \"40\",\n  \"residents\": [\n    \"https://ghibliapi.vercel.app/people/ba924631-068e-4436-b6de-f3283fa848f0\"\n  ],\n  \"films\": [\n    \"https://ghibliapi.vercel.app/films/0440483e-ca0e-4120-8c50-4c8cd9b965d6\"\n  ],\n  \"url\": \"https://ghibliapi.vercel.app/locations/11014596-71b0-4b3e-b8c0-1c4b15f28b9a\"\n}\n```","ref":"Ghibli.Location.html"},{"type":"function","title":"Ghibli.Location.all/0","doc":"","ref":"Ghibli.Location.html#all/0"},{"type":"function","title":"Ghibli.Location.get_by/1","doc":"","ref":"Ghibli.Location.html#get_by/1"},{"type":"type","title":"Ghibli.Location.t/0","doc":"","ref":"Ghibli.Location.html#t:t/0"},{"type":"module","title":"Ghibli.People","doc":"Handles fetching and parsing people endpoint from the Ghibli API. The data looks like this:\n```\n{\n  \"id\": \"ba924631-068e-4436-b6de-f3283fa848f0\",\n  \"name\": \"Cat King\",\n  \"gender\": \"Male\",\n  \"eye_color\": \"Emerald\",\n  \"hair_color\": \"Grey\",\n  \"films\": [\n    \"https://ghibliapi.vercel.app/films/90b72513-afd4-4570-84de-a56c312fdf81\"\n  ],\n  \"species\": \"https://ghibliapi.vercel.app/species/603428ba-8a86-4b0b-a9f1-65df6abef3d3\",\n  \"url\": \"https://ghibliapi.vercel.app/people/3042818d-a8bb-4cba-8180-c19249822d57\"\n}\n```","ref":"Ghibli.People.html"},{"type":"function","title":"Ghibli.People.all/0","doc":"","ref":"Ghibli.People.html#all/0"},{"type":"function","title":"Ghibli.People.get_by/1","doc":"","ref":"Ghibli.People.html#get_by/1"},{"type":"type","title":"Ghibli.People.t/0","doc":"","ref":"Ghibli.People.html#t:t/0"},{"type":"module","title":"Ghibli.Species","doc":"Handles fetching and parsing Species endpoint from Studio Ghibli API.\nThe data looks like this:\n```\n{\n \"id\": \"603428ba-8a86-4b0b-a9f1-65df6abef3d3\",\n \"name\": \"Cat\",\n \"classification\": \"Mammal\",\n \"eye_colors\": \"Brown, Black, Yellow, White, Emerald, Blue, Green\",\n \"hair_colors\": \"White, Black, Brown, Beige, Grey, Yellow\",\n \"people\": [\n   \"https://ghibliapi.vercel.app/people/7151abc6-1a9e-4e6a-9711-ddb50ea572ec\",\n   \"https://ghibliapi.vercel.app/people/f467e18e-3694-409f-bdb3-be891ade1106\",\n   \"https://ghibliapi.vercel.app/people/89026b3a-abc4-4053-ab1a-c6d2eea68faa\",\n   \"https://ghibliapi.vercel.app/people/6b3facea-ea33-47b1-96ce-3fc737b119b8\",\n   \"https://ghibliapi.vercel.app/people/3042818d-a8bb-4cba-8180-c19249822d57\",\n   \"https://ghibliapi.vercel.app/people/58d1973f-f247-47d7-9358-e56cb0d2b5a6\",\n   \"https://ghibliapi.vercel.app/people/a3d8e70f-46a0-4e5a-b850-db01620d6b92\",\n   \"https://ghibliapi.vercel.app/people/fc196c4f-0201-4ed2-9add-c6403f7c4d32\",\n   \"https://ghibliapi.vercel.app/people/466bc926-2024-4653-ac63-fe52f2dc8c7b\"\n ],\n \"films\": [\n   \"https://ghibliapi.vercel.app/films/58611129-2dbc-4a81-a72f-77ddfc1b1b49\",\n   \"https://ghibliapi.vercel.app/films/ea660b10-85c4-4ae3-8a5f-41cea3648e3e\",\n   \"https://ghibliapi.vercel.app/films/ff24da26-a969-4f0e-ba1e-a122ead6c6e3\",\n   \"https://ghibliapi.vercel.app/films/90b72513-afd4-4570-84de-a56c312fdf81\",\n   \"https://ghibliapi.vercel.app/films/2de9426b-914a-4a06-a3a0-5e6d9d3886f6\"\n ],\n \"url\": \"https://ghibliapi.vercel.app/species/603428ba-8a86-4b0b-a9f1-65df6abef3d3\"\n}\n```","ref":"Ghibli.Species.html"},{"type":"function","title":"Ghibli.Species.all/0","doc":"","ref":"Ghibli.Species.html#all/0"},{"type":"function","title":"Ghibli.Species.get_by/1","doc":"","ref":"Ghibli.Species.html#get_by/1"},{"type":"type","title":"Ghibli.Species.t/0","doc":"","ref":"Ghibli.Species.html#t:t/0"},{"type":"module","title":"Ghibli.Vehicles","doc":"Fetches Vehicles from API. The response from the API looks like this:\n```\n{\n  \"id\": \"923d70c9-8f15-4972-ad53-0128b261d628\",\n  \"name\": \"Sosuke's Boat\",\n  \"description\": \"A toy boat where Sosuke plays\",\n  \"vehicle_class\": \"Boat\",\n  \"length\": \"10\",\n  \"pilot\": \"https://ghibliapi.vercel.app/people/a10f64f3-e0b6-4a94-bf30-87ad8bc51607\",\n  \"films\": [\n    \"https://ghibliapi.vercel.app/films/758bf02e-3122-46e0-884e-67cf83df1786\"\n  ],\n  \"url\": \"https://ghibliapi.vercel.app/films/758bf02e-3122-46e0-884e-67cf83df1786\"\n}\n```","ref":"Ghibli.Vehicles.html"},{"type":"function","title":"Ghibli.Vehicles.all/0","doc":"","ref":"Ghibli.Vehicles.html#all/0"},{"type":"function","title":"Ghibli.Vehicles.get_by/1","doc":"","ref":"Ghibli.Vehicles.html#get_by/1"},{"type":"type","title":"Ghibli.Vehicles.t/0","doc":"","ref":"Ghibli.Vehicles.html#t:t/0"}],"proglang":"elixir","producer":{"name":"ex_doc","version":"0.37.3"},"content_type":"text/markdown"}